@@ -14,8 +14,12 @@ set_requester(function (request) {
 #with_mock_api <- capture_requests
 
 with_mock_api({
+  ## this has to skip if offline because the functions
+  ## return NULL when offline, but these functions may or may
+  ## not be compared against mocked responses
+
   test_that("core functions return tbl_df", {
-    #skip_on_cran()
+    skip_if_offline(host = "echodata.epa.gov")
 
     expect_s3_class(
       echoAirGetFacilityInfo(
@@ -90,8 +94,12 @@ with_mock_api({
 
 with_mock_api({
 
+  ## this has to skip if offline because the functions
+  ## return NULL when offline, but these functions may or may
+  ## not be compared against mocked responses
+
   test_that("core functions return sf", {
-    #skip_on_cran()
+    skip_if_offline(host = "echodata.epa.gov")
 
     expect_is(
       echoAirGetFacilityInfo(
